@@ -31,18 +31,28 @@ task :nodes do
 end
 
 def encrypted_for(node)
-  encrypted_files = Dir.glob("**/files/{default,host-#{node}}/*.{asc,gpg}") + Dir.glob('**/files/*.{asc,gpg}')
+  encrypted_files = Array(node.data['encrypted'])
+  if encrypted_files.empty?
+    encrypted_files = Dir.glob("**/files/{default,host-#{node.hostname}}/*.{asc,gpg}") + Dir.glob('**/files/*.{asc,gpg}')
+  end
   encrypted_files.each_with_object({}) do |key, hash|
     hash[key] = key.sub(/\.(asc|gpg)$/, '')
   end
 end
 
+desc 'list encrypted files per node'
+task :encrypted do
+  Chake.nodes.each do |node|
+    puts "#{node.hostname}: #{Array(encrypted_for(node).keys).join(', ')}"
+  end
+end
+
 def maybe_decrypt(node)
   if node.needs_upload?
     return yield
   end
 
-  files = encrypted_for(node.hostname)
+  files = encrypted_for(node)
   files.each do |encrypted, target|
     sh "gpg --use-agent --quiet --decrypt --output #{target} #{encrypted}"
   end
@@ -131,15 +141,15 @@ Chake.nodes.each do |node|
   task "upload:#{hostname}" => ["bootstrap:#{hostname}", :upload_common] do
     next unless node.needs_upload?
 
-    encrypted = encrypted_for(hostname)
+    encrypted = encrypted_for(node)
     rsync_excludes = (encrypted.values + encrypted.keys).map { |f| ['--exclude', f] }.flatten
     rsync_excludes << '--exclude' << '.git/'
     rsync_excludes << '--exclude' << 'cache/'
     rsync_excludes << '--exclude' << 'nodes/'
     rsync_excludes << '--exclude' << 'local-mode-cache/'
 
-    rsync = node.rsync + ['-avp'] + ENV.fetch('CHAKE_RSYNC_OPTIONS', '').split
-    rsync_logging = (Rake.application.options.silent && '--quiet') || '--verbose'
+    rsync = node.rsync + ['-ap'] + ENV.fetch('CHAKE_RSYNC_OPTIONS', '').split
+    rsync_logging = (Rake.application.options.trace && '--verbose') || '--quiet'
 
     hash_files = Dir.glob(File.join(Chake.tmpdir, '*.sha1sum'))
     files = Dir.glob('**/*').reject { |f| File.directory?(f) } - encrypted.keys - encrypted.values - hash_files
